aboutsummaryrefslogtreecommitdiffstats
path: root/src/main.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/main.c')
-rw-r--r--src/main.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/main.c b/src/main.c
index bb12270..2f2a320 100644
--- a/src/main.c
+++ b/src/main.c
@@ -13,7 +13,7 @@
*
* Initially inspired to the Tintin client by Peter Unold,
* Powwow contains no Tintin code.
- * The original program Cancan, written by Mattias Engdegård (Yorick)
+ * The original program Cancan, written by Mattias Engdeg�rd (Yorick)
* (f91-men@nada.kth.se) 1992-94,
* was greatly improved upon by Vivriel, Thuzzle and Ilie and then
* transformed from Cancan into Powwow by Cosmos who worked
@@ -159,7 +159,8 @@ aliasnode *sortedaliases; /* head of (ASCII) sorted alias list */
actionnode *actions; /* head of action list */
promptnode *prompts; /* head of prompt list */
marknode *markers; /* head of mark list */
-int a_nice = 0; /* default priority of new actions/marks */
+substnode *substitutions; /* head of substitution list */
+int a_nice = 0; /* default priority of new actions/marks/substitutions */
keynode *keydefs; /* head of key binding list */
delaynode *delays; /* head of delayed commands list */
delaynode *dead_delays; /* head of dead-delayed commands list */